@@ -47,7 +47,7 @@ public:
     static QString nameForType (kpEffectBlurSharpen::Type type);
 
 protected:
-    virtual kpImage applyEffect (const kpImage &image);
+    kpImage applyEffect (const kpImage &image) Q_DECL_OVERRIDE;
 
 protected:
     kpEffectBlurSharpen::Type m_type;
