@@ -32,14 +32,14 @@
 #include "views/kpUnzoomedThumbnailView.h"
 
 #include "kpLogCategories.h"
-#include <klocale.h>
-
 #include "document/kpDocument.h"
 #include "views/manager/kpViewManager.h"
 #include "kpViewScrollableContainer.h"
 
 #include <QScrollBar>
 
+#include <KLocalizedString>
+
 //---------------------------------------------------------------------
 
 struct kpUnzoomedThumbnailViewPrivate
